@@ -1,9 +1,7 @@
 """ Utility Objects and Functions """
 
-from .dictionary import Dictionary
 from .plugin import PluginManager
 
 __all__ = [
-    'Dictionary',
     'PluginManager',
 ]
